@@ -3,24 +3,16 @@ package Search::Xapian::QueryParser;
 use 5.006;
 use strict;
 use warnings;
-use Carp;
 
-require Exporter;
 require DynaLoader;
 
-our @ISA = qw(Exporter DynaLoader);
-# Items to export into caller's namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our @EXPORT_OK = ( );
-
-our @EXPORT = qw( );
+our @ISA = qw(DynaLoader);
 
 # Preloaded methods go here.
 
+# In a new thread, copy objects of this class to unblessed, undef values.
+sub CLONE_SKIP { 1 }
+
 use overload '='  => sub { $_[0]->clone() },
              'fallback' => 1;
 
@@ -109,9 +101,10 @@ documentation below. You can specify certain flags to modify the
 searching behaviour:
 
   FLAG_BOOLEAN, FLAG_PHRASE, FLAG_LOVEHATE, FLAG_BOOLEAN_ANY_CASE,
-  FLAG_WILDCARD, FLAG_PURE_NOT, FLAG_PARTIAL
+  FLAG_WILDCARD, FLAG_PURE_NOT, FLAG_PARTIAL, FLAG_SPELLING_CORRECTION,
+  FLAG_SYNONYM, FLAG_AUTO_SYNONYMS, FLAG_AUTO_MULTIWORD_SYNONYMS
 
-To specify multiple flags, "or" them together (with C<|>).  The
+To specify multiple flags, "bitwise or" them together (with C<|>).  The
 default flags are C<FLAG_PHRASE|FLAG_BOOLEAN|FLAG_LOVEHATE>
 
 =item add_prefix <field> <prefix>
